changeset 11604:6bab1bfac3bb libavcodec

Rename ff_parse_eval() to ff_eval_expr(). The new name expresses better what the function does.
author stefano
date Sun, 11 Apr 2010 22:32:01 +0000
parents 5cbea9fe32df
children 414a7cdaa54d
files eval.c eval.h ratecontrol.c
diffstat 3 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/eval.c	Sun Apr 11 20:04:15 2010 +0000
+++ b/eval.c	Sun Apr 11 22:32:01 2010 +0000
@@ -410,7 +410,7 @@
     return e;
 }
 
-double ff_parse_eval(AVExpr * e, const double *const_value, void *opaque) {
+double ff_eval_expr(AVExpr * e, const double *const_value, void *opaque) {
     Parser p;
 
     p.const_value= const_value;
@@ -425,7 +425,7 @@
     AVExpr * e = ff_parse(s, const_name, func1, func1_name, func2, func2_name, error);
     double d;
     if (!e) return NAN;
-    d = ff_parse_eval(e, const_value, opaque);
+    d = ff_eval_expr(e, const_value, opaque);
     ff_free_expr(e);
     return d;
 }
--- a/ratecontrol.c	Sun Apr 11 20:04:15 2010 +0000
+++ b/ratecontrol.c	Sun Apr 11 22:32:01 2010 +0000
@@ -339,7 +339,7 @@
         0
     };
 
-    bits= ff_parse_eval(rcc->rc_eq_eval, const_values, rce);
+    bits= ff_eval_expr(rcc->rc_eq_eval, const_values, rce);
     if (isnan(bits)) {
         av_log(s->avctx, AV_LOG_ERROR, "Error evaluating rc_eq \"%s\"\n", s->avctx->rc_eq);
         return -1;
--- a/eval.h	Sun Apr 11 20:04:15 2010 +0000
+++ b/eval.h	Sun Apr 11 22:32:01 2010 +0000
@@ -30,7 +30,7 @@
 
 /**
  * Parses and evaluates an expression.
  * Note, this is significantly slower than ff_parse_eval()
  *
  * @param s expression as a zero terminated string for example "1+2^3+5*5+sin(2/3)"
  * @param func1 NULL terminated array of function pointers for functions which take 1 argument
@@ -73,7 +73,7 @@
  * @param opaque a pointer which will be passed to all functions from func1 and func2
  * @return the value of the expression
  */
-double ff_parse_eval(AVExpr * e, const double *const_value, void *opaque);
+double ff_eval_expr(AVExpr * e, const double *const_value, void *opaque);
 
 /**
  * Frees a parsed expression previously created with ff_parse().
@@ -30,7 +30,7 @@
 /**
  * Parses and evaluates an expression.
- * Note, this is significantly slower than ff_parse_eval()
+ * Note, this is significantly slower than ff_eval_expr().
  *
  * @param s expression as a zero terminated string for example "1+2^3+5*5+sin(2/3)"